<?php

namespace Country\Country\Policies;

use Litepie\User\Contracts\UserPolicy;
use Country\Country\Models\Zone;

class ZonePolicy
{

    /**
     * Determine if the given user can view the zone.
     *
     * @param UserPolicy $user
     * @param Zone $zone
     *
     * @return bool
     */
    public function view(UserPolicy $user, Zone $zone)
    {
        if ($user->canDo('country.zone.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $zone->user_id;
    }

    /**
     * Determine if the given user can create a zone.
     *
     * @param UserPolicy $user
     * @param Zone $zone
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('country.zone.create');
    }

    /**
     * Determine if the given user can update the given zone.
     *
     * @param UserPolicy $user
     * @param Zone $zone
     *
     * @return bool
     */
    public function update(UserPolicy $user, Zone $zone)
    {
        if ($user->canDo('country.zone.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $zone->user_id;
    }

    /**
     * Determine if the given user can delete the given zone.
     *
     * @param UserPolicy $user
     * @param Zone $zone
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Zone $zone)
    {
        if ($user->canDo('country.zone.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $zone->user_id;
    }

    /**
     * Determine if the given user can verify the given zone.
     *
     * @param UserPolicy $user
     * @param Zone $zone
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Zone $zone)
    {
        if ($user->canDo('country.zone.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('country.zone.verify') 
        && $user->is('manager')
        && $zone->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given zone.
     *
     * @param UserPolicy $user
     * @param Zone $zone
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Zone $zone)
    {
        if ($user->canDo('country.zone.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
