<?php

namespace Country\Country\Providers;

use Illuminate\Support\ServiceProvider;

class CountryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'country');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'country');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('country', function ($app) {
            return $this->app->make('Country\Country\Country');
        });

        // Bind Country to repository
        $this->app->bind(
            'Country\Country\Interfaces\CountryRepositoryInterface',
            \Country\Country\Repositories\Eloquent\CountryRepository::class
        );
        // Bind Zone to repository
        $this->app->bind(
            'Country\Country\Interfaces\ZoneRepositoryInterface',
            \Country\Country\Repositories\Eloquent\ZoneRepository::class
        );

        $this->app->register(\Country\Country\Providers\AuthServiceProvider::class);
                $this->app->register(\Country\Country\Providers\EventServiceProvider::class);
        
        $this->app->register(\Country\Country\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['country'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('country/country.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/country')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/country')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
